Companies — Calcbench API Client documentation

# Companies

Lists of tickers and companies.

calcbench.companies.companies(SIC_codes=[], index=None, company_identifiers=[], entire_universe=False, include_most_recent_filing_dates=False, NAICS_codes=[])

  Return a DataFrame with company details

  Parameters

    - SIC_codes (`Sequence`[`int`]) – Sequence of SIC (Standard Industrial Classification) codes. eg. [1200, 1300]

    - index (`Optional`[`Literal`[‘DJIA’, ‘SP500’]]) – ‘DJIA’ or ‘SP500’

    - company_identifiers (`Sequence`[`Union`[`str`, `int`]]) – tickers

    - entire_universe (`bool`) – all of the companies in the Calcbench database

    - NAICS_codes (`Sequence`[`int`]) – Sequence of NAICS codes

  Return type

    `DataFrame`

  Returns

    Dataframe with data about companies

  Usage:

      >>> calcbench.tickers(company_identifiers=["msft", "orcl"])

calcbench.companies.companies_raw(SIC_codes=[], index=None, company_identifiers=[], entire_universe=False)

calcbench.companies.tickers(SIC_codes=[], index=None, company_identifiers=[], entire_universe=False, NAICS_codes=[])

  Get tickers

  Parameters

    - SIC_codes – Sequence of SIC (Standard Industrial Classification) codes. eg. [1200, 1300]

    - index – ‘DJIA’ or ‘SP500’

    - company_identifiers – tickers

    - entire_universe – all of the companies in the Calcbench database

    - NAICS_codes – Sequence of NAICS codes

  Returns

    list of tickers

  Usage:

      >>> calcbench.tickers(SIC_codes=[1100])